==> licq_1.3.0.orig.tar.gz: licq-1.3.0/plugins/osd/src/licq_osd.conf.h <==
static const char OSD_CONF[] =
"[Main]\n"
"# font which is used to display the osd\n"
"# you can get the available fonts for your machine from xfontsel\n"
"# i prefer this one - but it is not available everywhere\n"
"# Font=-*-lucida-*-r-*-*-24-*-*-*-*-*-iso8859-15\n"
"Font=-*-*-*-*-*-*-24-*-*-*-*-*-*-*\n"
"\n"
"# how long should a message be displayed\n"
"Timeout=5\n"
"\n"
"# how many lines should be displayed\n"
"Lines=5\n"
"\n"
"# maximum length of a line\n"
"Linelen=60\n"
"\n"
"# colour of the osd messages. look into your XFree86 rgb.txt for others\n"
"Colour=yellow\n"
"# colour of osd status change messages\n"
"ControlColour=grey\n"
"\n"
"# HPos is the horizontal position of the OSD\n"
"# valid values are left, right, center\n"
"HPos=left\n"
"\n"
"# VPos is the vertical position of the OSD\n"
"# valid values are top, bottom, middle\n"
"VPos=bottom\n"
"\n"
"# HOffset is the horizontal offset (=distance from left/right) of the OSD\n"
"# use this to displace the OSD on the second screen in multiscreen environments\n"
"HOffset=0\n"
"\n"
"# VOffset is the vertical offset (=distance from top/bottom) of the OSD\n"
"VOffset=90\n"
"\n"
"# when a message arrives before the previous one has timeouted -\n"
"# should we wait ?\n"
"# do only use 0 or 1. (true/false, on/off, ... do NOT work)\n"
"Wait=1\n"
"\n"
"# show logon/off of users ?\n"
"# 0=dont show\n"
"# 1=show all\n"
"# 2=show logon/off of Online notify users\n"
"Showlogon=0\n"
"\n"
"# show messages of users ?\n"
"# 0=dont show\n"
"# 1=show all\n"
"# 2=show messages of Online notify users\n"
"# 3=show only information that a message has been sent (like in sim)\n"
"# 4=show only information that a message has been sent (like in sim), only for Online notify users\n"
"Showmessages=1\n"
"\n"
"# how long after our logon or logoff should no message be displayed\n"
"# this is some sort of a hack:\n"
"# when we logon we get all the users who are online at the moment\n"
"# as an logon event. Usually you dont want to show all of them in a row\n"
"# (especially when wait = true), but only the ones who log on / off while\n"
"# you are online.\n"
"# note that this timeout is used when the plugin is loaded AFTER logon\n"
"# (via plugin manager). This is a side effect of this hack.\n"
"# set this to 0 if you want to get the logon messages on startup too\n"
"Quiettimeout=10\n"
"\n"
"# offset for shadow, 0 means no shadow\n"
"# draws a black shadow to the xosd text\n"
"ShadowOffset=0\n"
"\n"
"# offset for outline, 0 means no outline\n"
"# draws a black outline to the xosd text\n"
"OutlineOffset=2\n"
"\n"
"# colour for shadow. look into your XFree86 rgb.txt for others\n"
"ShadowColour=black\n"
"\n"
"# colour for outline. look into your XFree86 rgb.txt for others\n"
"OutlineColour=black\n"
"\n"
"# show status change of users?\n"
"# 0 = no\n"
"# 1 = all users\n"
"# 2 = only for online notify users\n"
"ShowStatusChange=0\n"
"\n"
"# this is an extra delay per character of the message.\n"
"# by using this you can achieve, that long messages are displayed\n"
"# longer than short ones\n"
"# The delay is specified in milliseconds, though only full seconds\n"
"# will take effect\n"
"# example: if DELAYPERCHARACTER is 200, then a message with 12 characters\n"
"# will be displayed for DISPLAYTIMEOUT+2 seconds\n"
"# (-->200*12 / 1000(1second) = 2.4, 0.4 ignored)\n"
"DelayPerCharacter=100\n"
"\n"
"# show an osd message whenever a user checks your auto response\n"
"# 0=dont show\n"
"# 1=show all\n"
"# 2=only for Online notify users\n"
"ShowAutoResponseCheck=0\n"
"\n"
"# messages which are sent via a secure connection will me marked with\n"
"# a (S)\n"
"MarkSecureMessages=0\n"
"# If this option is enabled, then the osd messages will only be shown\n"
"# if _you_ are in one of those stati. \n"
"# As long as this is commented out, the messages will _always_ be displayed\n"
"#ShowInModes = Online,FreeForChat,Away,NA,Occupied,DND,Invisible\n";

==> licq_1.3.5.orig.tar.gz: licq-1.3.5/plugins/osd/src/licq_osd.conf.h <==
static const char OSD_CONF[] =
"[Main]\n"
"# font which is used to display the osd\n"
"# you can get the available fonts for your machine from xfontsel\n"
"# i prefer this one - but it is not available everywhere\n"
"# Font=-*-lucida-*-r-*-*-24-*-*-*-*-*-iso8859-15\n"
"Font=-*-*-*-*-*-*-24-*-*-*-*-*-*-*\n"
"\n"
"# how long should a message be displayed\n"
"Timeout=5\n"
"\n"
"# how many lines should be displayed\n"
"Lines=5\n"
"\n"
"# maximum length of a line\n"
"Linelen=60\n"
"\n"
"# colour of the osd messages. look into your XFree86 rgb.txt for others\n"
"Colour=yellow\n"
"# colour of osd status change messages\n"
"ControlColour=grey\n"
"\n"
"# HPos is the horizontal position of the OSD\n"
"# valid values are left, right, center\n"
"HPos=left\n"
"\n"
"# VPos is the vertical position of the OSD\n"
"# valid values are top, bottom, middle\n"
"VPos=bottom\n"
"\n"
"# HOffset is the horizontal offset (=distance from left/right) of the OSD\n"
"# use this to displace the OSD on the second screen in multiscreen environments\n"
"HOffset=0\n"
"\n"
"# VOffset is the vertical offset (=distance from top/bottom) of the OSD\n"
"VOffset=90\n"
"\n"
"# when a message arrives before the previous one has timeouted -\n"
"# should we wait ?\n"
"# do only use 0 or 1. (true/false, on/off, ... do NOT work)\n"
"Wait=1\n"
"\n"
"# show logon/off of users ?\n"
"# 0=dont show\n"
"# 1=show all\n"
"# 2=show logon/off of Online notify users\n"
"Showlogon=0\n"
"\n"
"# show messages of users ?\n"
"# 0=dont show\n"
"# 1=show all\n"
"# 2=show messages of Online notify users\n"
"# 3=show only information that a message has been sent (like in sim)\n"
"# 4=show only information that a message has been sent (like in sim), only for Online notify users\n"
"Showmessages=1\n"
"\n"
"# how long after our logon or logoff should no message be displayed\n"
"# this is some sort of a hack:\n"
"# when we logon we get all the users who are online at the moment\n"
"# as an logon event. Usually you dont want to show all of them in a row\n"
"# (especially when wait = true), but only the ones who log on / off while\n"
"# you are online.\n"
"# note that this timeout is used when the plugin is loaded AFTER logon\n"
"# (via plugin manager). This is a side effect of this hack.\n"
"# set this to 0 if you want to get the logon messages on startup too\n"
"Quiettimeout=10\n"
"\n"
"# offset for shadow, 0 means no shadow\n"
"# draws a black shadow to the xosd text\n"
"ShadowOffset=0\n"
"\n"
"# offset for outline, 0 means no outline\n"
"# draws a black outline to the xosd text\n"
"OutlineOffset=2\n"
"\n"
"# colour for shadow. look into your XFree86 rgb.txt for others\n"
"ShadowColour=black\n"
"\n"
"# colour for outline. look into your XFree86 rgb.txt for others\n"
"OutlineColour=black\n"
"\n"
"# show status change of users?\n"
"# 0 = no\n"
"# 1 = all users\n"
"# 2 = only for online notify users\n"
"ShowStatusChange=0\n"
"\n"
"# this is an extra delay per character of the message.\n"
"# by using this you can achieve, that long messages are displayed\n"
"# longer than short ones\n"
"# The delay is specified in milliseconds, though only full seconds\n"
"# will take effect\n"
"# example: if DELAYPERCHARACTER is 200, then a message with 12 characters\n"
"# will be displayed for DISPLAYTIMEOUT+2 seconds\n"
"# (-->200*12 / 1000(1second) = 2.4, 0.4 ignored)\n"
"DelayPerCharacter=100\n"
"\n"
"# show an osd message whenever a user checks your auto response\n"
"# 0=dont show\n"
"# 1=show all\n"
"# 2=only for Online notify users\n"
"ShowAutoResponseCheck=0\n"
"\n"
"# messages which are sent via a secure connection will me marked with\n"
"# a (S)\n"
"MarkSecureMessages=0\n"
"\n"
"# If this option is enabled, then the osd messages will only be shown\n"
"# if _you_ are in one of those stati. \n"
"# As long as this is commented out, the messages will _always_ be displayed\n"
"#ShowInModes = Online,FreeForChat,Away,NA,Occupied,DND,Invisible\n"
"\n"
"# If ShowInModes specifies to not show anything, you might like to show\n"
"# messages (not status changes or so) in some more modes, so specify it here\n"
"#ShowMsgsInModes = DND\n";
